@@ -30,16 +30,17 @@ EXTRA_CFLAGS = ["-Werror", "-std=c99"]
 EXTRA_CFLAGS += shlex.split(os.environ.get("SYSREPO_EXTRA_CFLAGS", ""))
 EXTRA_LDFLAGS = shlex.split(os.environ.get("SYSREPO_EXTRA_LDFLAGS", ""))
 
-BUILDER.set_source(
-    "_sysrepo",
-    "#include <sysrepo.h>",
-    libraries=["sysrepo", "yang"],
-    extra_compile_args=EXTRA_CFLAGS,
-    extra_link_args=EXTRA_LDFLAGS,
-    include_dirs=HEADERS,
-    library_dirs=LIBRARIES,
-    py_limited_api=False,
-)
+with open(os.path.join(HERE, "source.c"), encoding="utf-8") as f:
+    BUILDER.set_source(
+        "_sysrepo",
+        f.read(),
+        libraries=["sysrepo", "yang"],
+        extra_compile_args=EXTRA_CFLAGS,
+        extra_link_args=EXTRA_LDFLAGS,
+        include_dirs=HEADERS,
+        library_dirs=LIBRARIES,
+        py_limited_api=False,
+    )
 
 if __name__ == "__main__":
     BUILDER.compile()
