@@ -293,6 +293,7 @@ class SysrepoSession:
         private_data: Any = None,
         asyncio_register: bool = False,
         include_implicit_defaults: bool = True,
+        include_deleted_values: bool = False,
         extra_info: bool = False,
     ) -> None:
         """
@@ -329,6 +330,8 @@ class SysrepoSession:
             monitored read file descriptors. Implies `no_thread=True`.
         :arg include_implicit_defaults:
             Include implicit default nodes in changes.
+        :arg include_deleted_values:
+            Include deleted nodes values in changes.
         :arg extra_info:
             When True, the given callback is called with extra keyword arguments
             containing extra information of the sysrepo session that gave origin to the
@@ -343,6 +346,7 @@ class SysrepoSession:
             private_data,
             asyncio_register=asyncio_register,
             include_implicit_defaults=include_implicit_defaults,
+            include_deleted_values=include_deleted_values,
             extra_info=extra_info,
         )
         sub_p = ffi.new("sr_subscription_ctx_t **")
@@ -732,7 +736,10 @@ class SysrepoSession:
 
     # begin: changes
     def get_changes(
-        self, xpath: str, include_implicit_defaults: bool = True
+        self,
+        xpath: str,
+        include_implicit_defaults: bool = True,
+        include_deleted_values: bool = False,
     ) -> Iterator[Change]:
         """
         Return an iterator that will yield all pending changes in the current session.
@@ -743,6 +750,8 @@ class SysrepoSession:
             appended to the XPath.
         :arg include_implicit_defaults:
             Include implicit default nodes.
+        :arg include_deleted_values:
+            Include deleted node values into the returned Change objects.
 
         :returns:
             An iterator that will yield `sysrepo.Change` objects.
@@ -778,6 +787,7 @@ class SysrepoSession:
                             prev_list=c2str(prev_list_p[0]),
                             prev_dflt=bool(prev_dflt_p[0]),
                             include_implicit_defaults=include_implicit_defaults,
+                            include_deleted_values=include_deleted_values,
                         )
                 except Change.Skip:
                     pass
@@ -1180,7 +1190,7 @@ class SysrepoSession:
         dnode = module.parse_data_dict(config, strict=strict, validate=False)
         self.replace_config_ly(dnode, module_name, timeout_ms=timeout_ms)
 
-    def validate(self) -> None:
+    def validate(self, module_name: str = None) -> None:
         """
         Perform the validation a datastore and any changes made in the current
         session, but do not apply nor discard them.
@@ -1188,12 +1198,16 @@ class SysrepoSession:
         Provides only YANG validation, apply-changes **subscribers will not be
         notified** in this case.
 
+        :arg module_name:
+            If specified, limits the validate operation only to this module and its
+            dependencies.
+
         :raises SysrepoError:
             If validation failed.
         """
         if self.is_implicit:
             raise SysrepoUnsupportedError("cannot validate with implicit sessions")
-        check_call(lib.sr_validate, self.cdata, 0)
+        check_call(lib.sr_validate, self.cdata, str2c(module_name), 0)
 
     def apply_changes(self, timeout_ms: int = 0) -> None:
         """
